<?php
/**
 * Portfolio Post Type
 *
 * @package   Portfolio_Post_Type
 * @author    Devin Price
 * @author    Gary Jones
 * @license   GPL-2.0+
 * @link      http://wptheming.com/portfolio-post-type/
 * @copyright 2011 Devin Price, Gary Jones
 */

/**
 * Portfolio post type.
 *
 * @package Portfolio_Post_Type
 * @author  Devin Price
 * @author  Gary Jones
 */
class products_Post_Type_Post_Type extends Gamajoproducts_Post_Type {
	/**
	 * Post type ID.
	 *
	 * @since 1.0.0
	 *
	 * @type string
	 */
	protected $post_type = 'products';

	/**
	 * Return post type default arguments.
	 *
	 * @since 1.0.0
	 *
	 * @return array Post type default arguments.
	 */
	protected function default_args() {
		$labels = array(
			'name'               => __( 'Theme Products', 'products-post-type' ),
			'singular_name'      => __( 'Theme Products Item', 'products-post-type' ),
			'menu_name'          => _x( 'Theme Products', 'admin menu', 'products-post-type' ),
			'name_admin_bar'     => _x( 'Theme Products Item', 'add new on admin bar', 'products-post-type' ),
			'add_new'            => __( 'Add New Item', 'products-post-type' ),
			'add_new_item'       => __( 'Add New Theme Products Item', 'products-post-type' ),
			'new_item'           => __( 'Add New Theme Products Item', 'products-post-type' ),
			'edit_item'          => __( 'Edit Theme Products Item', 'products-post-type' ),
			'view_item'          => __( 'View Item', 'products-post-type' ),
			'all_items'          => __( 'All Theme Products Items', 'products-post-type' ),
			'search_items'       => __( 'Search Theme Products', 'products-post-type' ),
			'parent_item_colon'  => __( 'Parent Theme Products Item:', 'products-post-type' ),
			'not_found'          => __( 'No Theme Products items found', 'products-post-type' ),
			'not_found_in_trash' => __( 'No Theme Products items found in trash', 'products-post-type' ),
		);

		$supports = array(
			'title',
			'thumbnail',
			
		);

		$args = array(
			'labels'          => $labels,
			'supports'        => $supports,
			'public'          => true,
			'capability_type' => 'post',
			'rewrite'         => array( 'slug' => 'products', ), // Permalinks format
			'menu_position'   => 5,
			'menu_icon'       => ( version_compare( $GLOBALS['wp_version'], '3.8', '>=' ) ) ? 'dashicons-portfolio' : false ,
			'has_archive'     => true,
		);

		return apply_filters( 'productsposttype_args', $args );
	}

	/**
	 * Return post type updated messages.
	 *
	 * @since 1.0.0
	 *
	 * @return array Post type updated messages.
	 */
	public function messages() {
		$post             = get_post();
		$post_type        = get_post_type( $post );
		$post_type_object = get_post_type_object( $post_type );

		$messages = array(
			0  => '', // Unused. Messages start at index 1.
			1  => __( 'Theme Products item updated.', 'products-post-type' ),
			2  => __( 'Custom field updated.', 'products-post-type' ),
			3  => __( 'Custom field deleted.', 'products-post-type' ),
			4  => __( 'Theme Products item updated.', 'products-post-type' ),
			/* translators: %s: date and time of the revision */
			5  => isset( $_GET['revision'] ) ? sprintf( __( 'Theme Products item restored to revision from %s', 'products-post-type' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
			6  => __( 'Theme Products item published.', 'products-post-type' ),
			7  => __( 'Theme Products item saved.', 'products-post-type' ),
			8  => __( 'Theme Products item submitted.', 'products-post-type' ),
			9  => sprintf(
				__( 'Theme Products item scheduled for: <strong>%1$s</strong>.', 'products-post-type' ),
				/* translators: Publish box date format, see http://php.net/date */
				date_i18n( __( 'M j, Y @ G:i', 'products-post-type' ), strtotime( $post->post_date ) )
			),
			10 => __( 'Theme Products item draft updated.', 'products-post-type' ),
		);

		if ( $post_type_object->publicly_queryable ) {
			$permalink         = get_permalink( $post->ID );
			$preview_permalink = add_query_arg( 'preview', 'true', $permalink );

			$view_link    = sprintf( ' <a href="%s">%s</a>', esc_url( $permalink ), __( 'View Theme Products item', 'products-post-type' ) );
			$preview_link = sprintf( ' <a target="_blank" href="%s">%s</a>', esc_url( $preview_permalink ), __( 'Preview Theme Products item', 'products-post-type' ) );

			$messages[1]  .= $view_link;
			$messages[6]  .= $view_link;
			$messages[9]  .= $view_link;
			$messages[8]  .= $preview_link;
			$messages[10] .= $preview_link;
		}

		return $messages;
	}
}