<?php
/**
 * Plugin Name: Theme Products Post Type
 * Plugin URI:  http://www.ninetheme.com/
 * Description: Enables a products post type and taxonomies.
 * Version:     1.0
 * Author:      Ninetheme
 * Author URI:  http://www.ninetheme.com/
 * Text Domain: products-post-type
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path: /languages
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Required files for registering the post type and taxonomies.
require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type.php';
require plugin_dir_path( __FILE__ ) . 'includes/interface-products-gamajo-registerable.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-gamajo-post-type.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-gamajo-taxonomy.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type-post-type.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type-taxonomy-category.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type-taxonomy-tag.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type-registrations.php';

// Instantiate registration class, so we can add it as a dependency to main plugin class.
$products_post_type_registrations = new Products_Post_Type_Registrations;

// Instantiate main plugin file, so activation callback does not need to be static.
$products_post_type = new Products_Post_Type( $products_post_type_registrations );

// Register callback that is fired when the plugin is activated.
register_activation_hook( __FILE__, array( $products_post_type, 'activate' ) );

// Initialise registrations for post-activation requests.
$products_post_type_registrations->init();

add_action( 'init', 'products_post_type_init', 100 );
/**
 * Adds styling to the dashboard for the post type and adds portfolio posts
 * to the "At a Glance" metabox.
 *
 * Adds custom taxonomy body classes to portfolio posts on the front end.
 *
 * @since 0.8.3
 */
function products_post_type_init() {
	if ( is_admin() ) {
		global $products_post_type_admin, $products_post_type_registrations;
		// Loads for users viewing the WordPress dashboard
		if ( ! class_exists( 'Gamajoproducts_Dashboard_Glancer' ) ) {
			require plugin_dir_path( __FILE__ ) . 'includes/class-products-gamajo-dashboard-glancer.php';  // WP 3.8
		}
		require plugin_dir_path( __FILE__ ) . 'includes/class-products-post-type-admin.php';
		$products_post_type_admin = new Products_Post_Type_Admin( $products_post_type_registrations );
		$products_post_type_admin->init();
	} else {
		// Loads for users viewing the front end
		if ( apply_filters( 'productsposttype_add_taxonomy_terms_classes', true ) ) {
			if ( ! class_exists( 'Gamajoproducts_Single_Entry_Term_Body_Classes' ) ) {
				require plugin_dir_path( __FILE__ ) . 'includes/class-products-gamajo-single-entry-term-body-classes.php';
			}
			$products_post_type_body_classes = new Gamajoproducts_Single_Entry_Term_Body_Classes;
			$products_post_type_body_classes->init( 'products' );
		}
	}
}
