<?php
/**
 *
 * @package WordPress
 * @subpackage proland
 * @since proland 1.0
 *
*/

/*************************************************
## Google Font
*************************************************/

function proland_fonts_url() {
	$proland_font_url = '';

	$Poppins 	= _x( 'on', 'Poppins font: on or off', 'proland' );
	$AbeeZee 	= _x( 'on', 'AbeeZee font: on or off', 'proland' );

	if ( 'off' !== $Poppins || 'off' !== $AbeeZee ) {
		$font_families = array();

		if ( 'off' !== $Poppins ) { $font_families[] = 'Poppins:400,300,500,600,700'; }
		if ( 'off' !== $AbeeZee ) { $font_families[] = 'AbeeZee:400,800,600'; }

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$proland_font_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $proland_font_url );
}

/*************************************************
## Styles and Scripts
*************************************************/

function proland_scripts() {

	if ( is_singular() && comments_open() ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Theme responsive grid framework
	wp_enqueue_style( 'bootstrap',						get_template_directory_uri() . '/css/lib/bootstrap.min.css', false, '1.0');

	if ( is_rtl() ) {
		wp_enqueue_style( 'bootstrap-rtl',				get_template_directory_uri() . '/css/lib/bootstrap-rtl.css', false, '1.0');
		wp_enqueue_style( 'proland-rtl',				get_template_directory_uri() . '/css/rtl.css', false, '1.0');
	}

	// Responsive jQuery modal window plugin
	wp_enqueue_style( 'magnific-popup',					get_template_directory_uri() . '/vendors/magnific-popup/magnific-popup.css', false, '1.0');

	if ( ot_get_option( 'proland_animate' ) !='off' ){
	// Animate library
	wp_enqueue_style( 'ani2mate',						get_template_directory_uri() . '/css/plugins/animate.css', false, '1.0');
	wp_deregister_style( 'animate' );  // VC plugin hack
	wp_deregister_style( 'animate-css' ); // VC plugin hack
	}

	// Theme preloader codes
	wp_enqueue_style( 'proland-preloader',				get_template_directory_uri() . '/css/plugins/preloader.css', false, '1.0');

	// Custom woocommerce
	if(function_exists('WC')) {
		wp_enqueue_style( 'proland-woo',  				get_template_directory_uri() . '/css/lib/woo.css', false, '1.0');
	}

	// Main styles
	wp_enqueue_style( 'proland-style',					get_template_directory_uri() . '/css/style.css', false, '5.0');

	// Theme color scheme
	wp_enqueue_style( 'proland-color-scheme',			get_template_directory_uri() . '/css/themes/blue-orange.css', false, '1.0');


	// Font icon libraries
	if ( ot_get_option( 'proland_line_v' ) !='off' ){
		wp_enqueue_style( 'lineicons',					get_template_directory_uri() . '/css/plugins/lineicons.css', false, '1.0');
	}
	if ( ot_get_option( 'proland_awe_v' ) !='off' ){
		wp_enqueue_style( 'font-awesome' );
	}
	if ( ot_get_option( 'proland_vc_line_v' ) !='off' ){
		wp_enqueue_style( 'vc_linecons' );
	}
	if ( ot_get_option( 'proland_op_v' ) !='off' ){
		wp_enqueue_style( 'vc_openiconic' );
	}
	if ( ot_get_option( 'proland_typ_v' ) !='off' ){
		wp_enqueue_style( 'vc_typicons' );
	}
	if ( ot_get_option( 'proland_ent_v' ) !='off' ){
		wp_enqueue_style( 'vc_entypo' );
	}
	if ( ot_get_option( 'proland_mono_v' ) !='off' ){
		wp_enqueue_style( 'vc_monosocialiconsfont' );
	}

	// Flexslider for blog gallery posts - register oldu
	wp_register_style( 'proland-custom-flexslider',  	get_template_directory_uri() . '/js/theme/flexslider/flexslider.css', false, '1.0');

	// Default WordPress styles
	wp_enqueue_style( 'proland-wordpress',  			get_template_directory_uri() . '/css/lib/wordpress.css', false, '1.0');

	// Theme style update file
	wp_enqueue_style( 'proland-update',  				get_template_directory_uri() . '/css/lib/update.css', false, '1.0');


	// Google webfont loader
	wp_enqueue_style( 'proland-fonts-load', 			proland_fonts_url(), array(), null );

	// WordPress default
	wp_enqueue_style( 'proland-costum-style', 		get_stylesheet_uri() );
	wp_enqueue_style( 'style', 							get_stylesheet_uri() );


	/*************************************************
	## Theme Jquery Files
	*************************************************/

	// Bootstrap grid framework jquery library
	wp_enqueue_script( 'bootstrap', 	 				get_template_directory_uri() .  '/js/lib/bootstrap.min.js', array('jquery'), '1.0', true);

	// Jquery image / video / iframe responsive plugin
	wp_enqueue_script( 'magnific-popup', 	 			get_template_directory_uri() .  '/vendors/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '1.0', true);

	wp_enqueue_script( 'wow', 	 						get_template_directory_uri() .  '/js/plugins/wow.min.js', 			array('jquery'), '1.0', true);
	wp_enqueue_script( 'validate', 	 					get_template_directory_uri() .  '/js/plugins/validate.js', 			array('jquery'), '1.0', true);
	wp_enqueue_script( 'ytplayer', 	 					get_template_directory_uri() .  '/js/plugins/ytplayer.js', 			array('jquery'), '1.0', true);

	if ( is_page_template( 'unlimited-page.php' ) ){
		// Contact forms
		wp_enqueue_script( 'proland-pre-order', 	 	get_template_directory_uri() .  '/js/includes/pre-order.js', 		array('jquery'), '1.0', true);
	}

	// Google maps api & customization
	$proland_map_api_key 		= ot_get_option( 'proland_map_api_key' );
	$proland_map_api_key_out 	= ( $proland_map_api_key != '') ? '' .  $proland_map_api_key  . '' : 'AIzaSyCS6nP8qI2xdoj1yrHHTE0SKs5PFXeWr_8';

	wp_register_script( 'google-map-api',           	'https://maps.googleapis.com/maps/api/js?key='. $proland_map_api_key_out .'', '3.0.0', true);
	wp_register_script( 'gmaps', 	 					get_template_directory_uri() .  '/js/plugins/gmaps.min.js', 		array('jquery'), '1.0', true);
	wp_register_script( 'proland-google-map', 	 		get_template_directory_uri() .  '/js/plugins/google-map.js', 		array('jquery'), '1.0', true);

	// Flexslider for blog gallery posts
	wp_register_script( 'flexslider', 	 				get_template_directory_uri() .  '/js/theme/jquery.flexslider.js', 	array('jquery'), '1.0', true);

	// Responsive video iframe plugin
	wp_register_script( 'fitvids', 	 					get_template_directory_uri() .  '/js/theme/jquery.fitvids.js', 		array('jquery'), '1.0', true);

	// Blogroll custom jquery setting file
	wp_register_script( 'proland-blog-script', 			get_template_directory_uri() .  '/js/theme/blog-script.js', 		array('jquery'), '1.0', true);

	// Theme jquery settings file
	if ( ot_get_option( 'proland_relative_header' ) !='off' ){
		wp_enqueue_script( 'proland-sticky', 	 			get_template_directory_uri() .  '/js/custom/sticky.js', 			array('jquery'), '1.0', true);
	}

	wp_register_script( 'proland-product-js', 	 		get_template_directory_uri() .  '/js/custom/product.js', 			array('jquery'), '1.0', true);
	wp_enqueue_script(  'proland-main-js', 	 			get_template_directory_uri() .  '/js/main.js', 						array('jquery'), '1.0', true);

	// HTML5 and IE browser SUPPORT
	wp_enqueue_script(  'html5shiv', 					get_template_directory_uri()  .  '/js/html5shiv.min.js', 			array('jquery'), '3.7.2', false );
	wp_script_add_data( 'html5shiv', 					'conditional', 'lt IE 9' );

	wp_enqueue_script(  'respond', 						get_template_directory_uri()  .  '/js/respond.min.js', 				array('jquery'), '1.4.2', false );
	wp_script_add_data( 'respond', 						'conditional', 'lt IE 9' );

}

add_action( 'wp_enqueue_scripts', 'proland_scripts' );


/*************************************************
## Admin style and scripts
*************************************************/

function proland_admin_style() {

	// Update CSS within in Admin
	wp_enqueue_style('proland-custom-admin', get_template_directory_uri().'/admin/admin.css');

}
add_action('admin_enqueue_scripts', 'proland_admin_style');



/*************************************************
## Theme option & Metaboxes & shortcodes
*************************************************/

	if ( function_exists('vc_set_as_theme' ) ) {
		require_once get_template_directory() . '/includes/visualcomposer/visual-shortcodes.php';
	}

	// Metabox plugin check
	if ( ! function_exists( 'rwmb_meta' ) ) {
		function rwmb_meta( $key, $args = '', $post_id = null ) {
			return false;
		}
	}

	// Theme breadcrumb
	if ( ! function_exists( 'proland_breadcrubms' ) ) {
		require_once get_template_directory() . '/includes/breadcrumb.php';
	}

	// Woocommerce
	if( function_exists( 'WC' ) ) {
		require_once get_template_directory() . '/includes/shop/functions.php';
		require_once get_template_directory() . '/includes/shop/woocommerce.php';
	}

	// Theme colors
	require_once get_template_directory() . '/includes/color-scheme.php';

	// Theme css setting file
	require_once get_template_directory() . '/includes/custom-style.php';

	require_once get_template_directory() . '/includes/post-like.php';

	// Theme navigation and pagination options
	require_once get_template_directory() . '/includes/template-tags.php';

	// Automatic image crop plugin
	require_once get_template_directory() . '/includes/aq_resizer.php';

	// Theme post and page meta plugin for customization and more features
	require_once get_template_directory() . '/includes/custom-metaboxes/page-metaboxes.php';


   // Option tree controllers
	if ( ! class_exists( 'OT_Loader' )){

		function ot_get_option() {
			return false;
		}

	}

	// add filter for  options panel loader
	add_filter( 'ot_show_pages', 		'__return_false' );
	add_filter( 'ot_show_new_layout', 	'__return_false' );

    add_filter( 'woocommerce_enable_setup_wizard', '__return_false' );

	// Theme options admin panel setings file
	require_once get_template_directory() . '/includes/theme-options.php';

	// Theme customize css setting file
	require_once get_template_directory() . '/includes/custom-style.php';


	/*************************************************
	## OPTION TREE WEBFONTS API
	*************************************************/

	add_filter( 'ot_google_fonts_api_key', 'proland_change_ot_google_fonts_api_key' );

	function proland_change_ot_google_fonts_api_key( $key ) {
	  return "AIzaSyA2rMBHxvoyNhL8gTR2dITpGgXOdAiW6IQ";
	}



	/*************************************************
	## ADMIN NOTICES
	*************************************************/


	function proland_theme_activation_notice()
	{
	    global $current_user;

	    $user_id = $current_user->ID;

	    if (!get_user_meta($user_id, 'proland_theme_activation_notice')) {
	        ?>

			<div class="updated notice">

                <p>
                   <?php
                       echo sprintf(
                       esc_html__('If you need help about demodata installation, please read docs and %s', 'proland'),
                       '<a target="_blank" href="' . esc_url('https://ninetheme.com/contact/') . '">
                       ' . esc_html__('Contact', 'proland') . '
                       </a> ' . esc_html__(' - ', 'proland') . ' <a href="?proland-ignore-notice">' . esc_html__('Dismiss', 'proland') . '</a>');
                   ?>
                </p>
		    </div>

	<?php
	    }
	}


	add_action('admin_notices', 'proland_theme_activation_notice');

	function proland_theme_activation_notice_ignore()
	{
	    global $current_user;

	    $user_id = $current_user->ID;

	    if (isset($_GET['proland-ignore-notice'])) {
	        add_user_meta($user_id, 'proland_theme_activation_notice', 'true', true);
	    }
	}
	add_action('admin_init', 'proland_theme_activation_notice_ignore');




/*************************************************
## Theme Setup
*************************************************/

if ( ! isset( $content_width ) ) $content_width = 960;

function proland_theme_setup() {

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, icons, and column width.
	*/
	add_editor_style ( 'custom-editor-style.css' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	* Enable support for Post Thumbnails on posts and pages.
	*
	* See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	*/
	add_theme_support( 'post-thumbnails' );

	// Theme customizer and tag support
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'woocommerce' );
	/*
	* Enable support for Post Formats.
	*
	* See: https://codex.wordpress.org/Post_Formats
	*/
	add_theme_support( 'post-formats', array('gallery', 'link', 'image', 'quote', 'video', 'audio', 'aside', 'chat', 'status'));

	add_image_size( 'proland_member_thumb', 650, 650, true); 		// Team Member thumbnails

	// Make theme available for translation
	// Translations can be filed in the /languages/ directory
	load_theme_textdomain( 'proland', get_template_directory() . '/languages' );


	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'proland' ),
	) );

}
add_action( 'after_setup_theme', 'proland_theme_setup' );

/*************************************************
## Widget columns
*************************************************/

function proland_widgets_init() {

	register_sidebar( array(
		'name' 			=> esc_html__( 'Page Sidebar', 'proland' ),
		'id' 			=> 'sidebar-1',
		'description'   => esc_html__( 'These are widgets for the pages.','proland' ),
		'before_widget' => '<div class="widget  %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>'
	) );

	register_sidebar( array(
		'name' 			=> esc_html__( 'Woocommerce', 'proland' ),
		'id' 			=> 'shop-page-sidebar',
		'description'   => esc_html__( 'This widget for the Woocommerce pages widget area','proland' ),
		'before_widget' => '<div class="widget  %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>'
	) );

	register_sidebar( array(
		'name' 			=> esc_html__( 'Widgetize footer', 'proland' ),
		'id' 			=> 'footer',
		'description'   => esc_html__( 'These are widgets for the Shop single Sidebar.','proland' ),
		'before_widget' => '<div class="col-sm-3"><div class="widget  %2$s">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h5 class="uppercase">',
		'after_title'   => '</h5>'
	) );

}
add_action( 'widgets_init', 'proland_widgets_init' );


/*************************************************
## Body class.
@link    http://codex.wordpress.org/Function_Reference/body_class
*************************************************/

function proland_body_classes( $classes ) {
	$classes[] = ot_get_option( 'proland_layout_type' );
	return $classes;
}
 // Add classes to the body tag
add_action( 'body_class', 'proland_body_classes' );

/*************************************************
## Include the TGM_Plugin_Activation class.
*************************************************/

require_once get_template_directory() . '/includes/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'proland_register_required_plugins' );
function proland_register_required_plugins() {

	$url = 'https://ninetheme.com/documentation';

    $plugins = array(
		array(
            'name'          => esc_html__('Contact Form 7', "proland"),
            'slug'          => 'contact-form-7',
        ),
		array(
            'name'          => esc_html__('Custom Sidebars', "proland"),
            'slug'          => 'custom-sidebars',
			'required'      => false,
        ),
        array(
            'name'          => esc_html__('Meta Box', "proland"),
            'slug'          => 'meta-box',
			'required'      => true,
        ),
        array(
            'name'          => esc_html__('Woocommerce', "proland"),
            'slug'          => 'woocommerce',
			'required'      => false,
        ),
		array(
			'name'			=> esc_html__('Team post type', 'proland'),
			'slug'			=> 'team-post-type',
			'source'        => $url . '/plugins/team-post-type.zip',
			'required'		=> false,
		),
      	array(
			'name'				=> esc_html__('Theme Options Panel', "proland"),
			'slug'			=> 'option-tree',
			'source'		=> $url . '/plugins/option-tree.zip',
			'required'		=> true,
		),
		array(
			'name'         	=> esc_html__('Price Tables', 'proland'),
			'slug'         	=> 'price-post-type',
			'source'        => $url . '/plugins/price-post-type.zip',
			'required'     	=> true,
		),
		array(
			'name'         	=> esc_html__('Product Post Type', 'proland'),
			'slug'         	=> 'products-post-type',
			'source'        => $url . '/plugins/products-post-type.zip',
			'required'     	=> true,
		),
		array(
			'name'         	=> esc_html__('Metabox Show/Hide', "proland"),
			'slug'         	=> 'meta-box-show-hide',
			'source'        => $url . '/plugins/meta-box-show-hide.zip',
			'required'     	=> true,
		),
		array(
			'name'		   	=> esc_html__('Envato Auto Update Theme', "proland"),
			'slug'		   	=> 'envato-market',
			'source'        => $url . '/plugins/envato-market.zip',
			'required'	   	=> false,
		),
		array(
			'name'         	=> esc_html__('Visual Composer', "proland"),
			'slug'         	=> 'visual_composer',
			'source'        => $url . '/plugins/visual_composer.zip',
			'required'     	=> true,
		),
		array(
			'name'         	=> esc_html__('Revolution Slider', "proland"),
			'slug'         	=> 'revolution_slider',
			'source'        => $url . '/plugins/revolution_slider.zip',
			'required'     	=> false,
		),
		array(
			'name'         	=> esc_html__('Metabox Tabs', "proland"),
			'slug'         	=> 'meta-box-tabs',
			'source'        => $url . '/plugins/meta-box-tabs.zip',
			'required'     	=> true,
		),
		array(
            'name'          => esc_html__('WP Proland Shortcodes', "proland"),
            'slug'          => 'proland-shortcodes',
            'source'        => get_template_directory() . '/plugins/proland-shortcodes.zip',
            'required'      => true,
            'version'       => '1.4.6',
        ),

    );

	$config = array(
		'id'           => 'proland',
		'default_path' => '',
		'menu'         => 'tgmpa-install-plugins',
		'parent_slug'  => 'themes.php',
		'capability'   => 'edit_theme_options',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '',
		'is_automatic' => true,
		'message'      => '',
	);
	tgmpa( $plugins, $config );
}




/*************************************************
## Register Menu
*************************************************/

class Proland_Wp_Bootstrap_Navwalker extends Walker_Nav_Menu {

	/**
	 * @see Walker::start_lvl()
	 * @since 3.0.0
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		$output .= "\n$indent<ul role=\"menu\" class=\"sub-menu dropdown-menu\">\n";
	}

	/**
	 * @see Walker::start_el()
	 * @since 3.0.0
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		/**
		 * Dividers, Headers or Disabled
		 */
		if ( strcasecmp( $item->attr_title, 'divider' ) == 0 && $depth === 1 ) {
			$output .= $indent . '<li role="presentation" class="divider item-has-children dropdown">';
		} else if ( strcasecmp( $item->title, 'divider') == 0 && $depth === 1 ) {
			$output .= $indent . '<li role="presentation" class="divider item-has-children dropdown">';
		} else if ( strcasecmp( $item->attr_title, 'dropdown-header item-has-children dropdown') == 0 && $depth === 1 ) {
			$output .= $indent . '<li role="presentation" class="dropdown-header item-has-children dropdown">' . esc_attr( $item->title );
		} else if ( strcasecmp($item->attr_title, 'disabled' ) == 0 ) {
			$output .= $indent . '<li role="presentation" class="disabled"><a href="#">' . esc_attr( $item->title ) . '</a>';
		} else {

			$class_names = $value = '';

			$classes = empty( $item->classes ) ? array() : (array) $item->classes;
			$classes[] = 'menu-item-' . $item->ID;

			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );

			if ( $args->has_children )
				$class_names .= ' sub item-has-children dropdown';

			if ( in_array( 'current-menu-item', $classes ) )
				$class_names .= ' active';

			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
			$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

			$output .= $indent . '<li' . $id . $value . $class_names .'>';

			$atts = array();
			$atts['title']  = ! empty( $item->title )	? $item->title	: '';
			$atts['target'] = ! empty( $item->target )	? $item->target	: '';
			$atts['rel']    = ! empty( $item->xfn )		? $item->xfn	: '';

			// If item has_children add atts to a.
			if ( $args->has_children && $depth === 0 ) {
				$atts['href']   		= '#';
				$atts['data-toggle']	= 'dropdown';
				$atts['class']			= 'dropdown-toggle';
			} else {
				$atts['href'] = ! empty( $item->url ) ? $item->url : '';
			}

			$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args );

			$attributes = '';
			foreach ( $atts as $attr => $value ) {
				if ( ! empty( $value ) ) {
					$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
				}
			}

			$item_output = $args->before;

			/*
			 * Glyphicons
			 **/
			if ( ! empty( $item->attr_title ) )
				$item_output .= '<a'. $attributes .'><span class=" ' . esc_attr( $item->attr_title ) . '"></span>&nbsp;';
			else
				$item_output .= '<a'. $attributes .'>';

			$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
			$item_output .= ( $args->has_children && 0 === $depth ) ? ' <span class="caret"></span></a>' : '</a>';
			$item_output .= $args->after;

			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}
	}

	/**
	 * Traverse elements to create list from elements.
	 **/
	public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {
        if ( ! $element )
            return;

        $id_field = $this->db_fields['id'];

        // Display this element.
        if ( is_object( $args[0] ) )
           $args[0]->has_children = ! empty( $children_elements[ $element->$id_field ] );

        parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    }

	/**
	 * Menu Fallback
	 **/
	public static function fallback( $args ) {
		if ( current_user_can( 'manage_options' ) ) {

			extract( $args );

			$fb_output = null;

			if ( $container ) {
				$fb_output = '<' . $container;

				if ( $container_id )
					$fb_output .= ' id="' . $container_id . '"';

				if ( $container_class )
					$fb_output .= ' class="' . $container_class . '"';

				$fb_output .= '>';
			}

			$fb_output .= '<ul';

			if ( $menu_id )
				$fb_output .= ' id="' . $menu_id . '"';

			if ( $menu_class )
				$fb_output .= ' class="' . $menu_class . '"';

			$fb_output .= '>';
			$fb_output .= '<li><a href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '">'. esc_html_e( 'Add a menu','proland' ) .'</a></li>';
			$fb_output .= '</ul>';

			if ( $container )
				$fb_output .= '</' . $container . '>';

			echo wp_kses($fb_output,proland_allowed_html());
		}
	}
}

/*************************************************
## change author / user avatar  class
*************************************************/


function proland_change_avatar_css($class) {
	$class = str_replace("class='avatar", "class='img-circle img-thumbnail", $class) ;
	return $class;
}
add_filter('get_avatar','proland_change_avatar_css');

/*************************************************
## change edit comment link class
*************************************************/

function  proland_edit_comment_link( $output ) {
	$proland_custom_class = 'btn-link';
	return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $proland_custom_class, $output, 1 );
}
add_filter( 'edit_comment_link', 'proland_edit_comment_link' );

/*************************************************
## replace reply link class
*************************************************/

function proland_replace_reply_link_class($class){
    $class = str_replace("class='comment-reply-link", "class='btn-link m-left-15", $class);
    return $class;
}
add_filter('comment_reply_link', 'proland_replace_reply_link_class');

/*************************************************
## User author box social links
*************************************************/

function proland_contactmethods( $contactmethods ) {

	$contactmethods['behance'] 		= esc_html__('Behance', 'proland');
	$contactmethods['delicious'] 	= esc_html__('Delicious', 'proland');
	$contactmethods['deviantart'] 	= esc_html__('Deviantart', 'proland');
	$contactmethods['digg'] 		= esc_html__('Digg', 'proland');
	$contactmethods['dribbble'] 	= esc_html__('Dribbble', 'proland');
	$contactmethods['facebook'] 	= esc_html__('Facebook', 'proland');
	$contactmethods['flickr'] 		= esc_html__('Flickr', 'proland');
	$contactmethods['github'] 		= esc_html__('Github', 'proland');
	$contactmethods['google'] 		= esc_html__('Google', 'proland');
	$contactmethods['googleplus'] 	= esc_html__('Google Plus', 'proland');
	$contactmethods['html5'] 		= esc_html__('Html5', 'proland');
	$contactmethods['instagram'] 	= esc_html__('Instagram', 'proland');
	$contactmethods['linkedin'] 	= esc_html__('Linkedin', 'proland');
	$contactmethods['pinterest'] 	= esc_html__('Pinterest', 'proland');
	$contactmethods['reddit'] 		= esc_html__('Reddit', 'proland');
	$contactmethods['rss'] 			= esc_html__('Rss', 'proland');
	$contactmethods['sharethis'] 	= esc_html__('Sharethis', 'proland');
	$contactmethods['skype'] 		= esc_html__('Skype', 'proland');
	$contactmethods['soundcloud'] 	= esc_html__('Soundcloud', 'proland');
	$contactmethods['spotify'] 		= esc_html__('Spotify', 'proland');
	$contactmethods['stackoverflow'] = esc_html__('Stackoverflow', 'proland');
	$contactmethods['steam'] 		= esc_html__('Steam', 'proland');
	$contactmethods['stumbleUpon'] 	= esc_html__('StumbleUpon', 'proland');
	$contactmethods['tumblr'] 		= esc_html__('Tumblr', 'proland');
	$contactmethods['twitter'] 		= esc_html__('Twitter', 'proland');
	$contactmethods['vimeo'] 		= esc_html__('Vimeo', 'proland');
	$contactmethods['windows'] 		= esc_html__('Windows', 'proland');
	$contactmethods['wordpress'] 	= esc_html__('Wordpress', 'proland');
	$contactmethods['yahoo'] 		= esc_html__('Yahoo', 'proland');
	$contactmethods['youtube'] 		= esc_html__('Youtube', 'proland');
	$contactmethods['xing'] 		= esc_html__('Xing', 'proland');

return $contactmethods;
}

add_filter( 'user_contactmethods', 'proland_contactmethods' );

/*************************************************
## proland Comment
*************************************************/

	if ( ! function_exists( 'proland_comment' ) ) :
	function proland_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
	case 'pingback' :
	case 'trackback' :
	?>

   <div class="container">
   <div class="comments">
   <article class="post pingback">
   <p><?php esc_html_e( 'Pingback:', 'proland' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'proland' ), ' ' ); ?></p>
	<?php
	break;
	default :
	?>
     <div class=" m0 comments-row m-bottom-37">
		<div class=" m0 comment">
			<a class="commenter-link"><?php echo get_avatar( $comment, 80 ); ?></a>
			<h3 class="commenter-name"><a><?php comment_author(); ?></a> <small class="pull-right"><a href="<?php comment_author_link(); ?>"><?php comment_date(); ?> <?php esc_html_e( 'at', 'proland' ); ?> <?php comment_time(); ?></a></small></h3>
			<?php comment_text(); ?>
			<?php edit_comment_link( esc_html__( 'Edit', 'proland' ), ' ' ); ?> <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div>
	</div>
	<?php
	break;
	endswitch;
	}
	endif;

	/*************************************************
	## SANITIZE MODIFIED VC-ELEMENTS OUTPUT
	*************************************************/


	if (!function_exists('proland_vc_sanitize_data')) {
	    function proland_vc_sanitize_data($html_data)
	    {
	        return $html_data;
	    }
	}


/**********************************
## THEME ALLOWED HTML TAG
/**********************************/


if (! function_exists('proland_allowed_html')) {
    function proland_allowed_html()
    {
        $allowed_tags = array(
        'a' => array(
            'class' => array(),
            'href'  => array(),
            'rel'   => array(),
            'title' => array(),
            'target' => array(),
        ),
        'abbr' => array(
            'title' => array(),
        ),
        'iframe' => array(
            'src' => array(),
        ),
        'b' => array(),
        'br' => array(),
        'blockquote' => array(
            'cite'  => array(),
        ),
        'cite' => array(
            'title' => array(),
        ),
        'code' => array(),
        'del' => array(
            'datetime' => array(),
            'title' => array(),
        ),
        'dd' => array(),
        'div' => array(
            'class' => array(),
            'title' => array(),
            'style' => array(),
        ),
        'dl' => array(),
        'dt' => array(),
        'em' => array(),
        'h1' => array(),
        'h2' => array(),
        'h3' => array(),
        'h4' => array(),
        'h5' => array(),
        'h6' => array(),
        'i' => array(
            'class'  => array(),
        ),
        'img' => array(
            'alt'    => array(),
            'class'  => array(),
            'height' => array(),
            'src'    => array(),
            'width'  => array(),
        ),
        'li' => array(
            'class' => array(),
        ),
        'ol' => array(
            'class' => array(),
        ),
        'p' => array(
            'class' => array(),
        ),
        'q' => array(
            'cite' => array(),
            'title' => array(),
        ),
        'span' => array(
            'class' => array(),
            'title' => array(),
            'style' => array(),
        ),
        'strike' => array(),
        'strong' => array(),
        'ul' => array(
            'class' => array(),
        ),
    );

        return $allowed_tags;
    }
}


/*************************************************
## THEME SETUP WIZARD
    https://github.com/richtabor/MerlinWP
*************************************************/


require_once get_parent_theme_file_path( '/includes/merlin/vendor/autoload.php' );
require_once get_parent_theme_file_path( '/includes/merlin/class-merlin.php' );
require_once get_parent_theme_file_path( '/includes/demo-wizard-config.php' );

function proland_merlin_local_import_files() {
	return array(
		array(

			'import_file_name'              => 'Demo Import',
            // xml data
			'local_import_file'             => get_parent_theme_file_path( 'includes/merlin/demodata/data.xml' ),
            // widget data
			'local_import_widget_file'      => get_parent_theme_file_path( 'includes/merlin/demodata/widgets.wie' ),
            // option tree -> theme options
            'local_import_option_tree_file' => get_parent_theme_file_path( 'includes/merlin/demodata/optiontree.txt' ),

		)
	);
}
add_filter( 'merlin_import_files', 'proland_merlin_local_import_files' );


/**
 * Execute custom code after the whole import has finished.
 */
function proland_merlin_after_import_setup() {
	// Assign menus to their locations.
	$primary = get_term_by( 'name', 'Menu 1', 'nav_menu' );

	set_theme_mod(
		'nav_menu_locations', array(
            'primary' => $primary->term_id,
		)
	);

	// Assign front page and posts page (blog page).
	$front_page_id = get_page_by_title( 'Homepage Woocommerce' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );

}
add_action( 'merlin_after_all_import', 'proland_merlin_after_import_setup' );


add_action('init', 'do_output_buffer'); function do_output_buffer() { ob_start(); }



function cursornt_merlin_generate_child_functions_php( $output, $slug ) {
$slug_no_hyphens = strtolower( preg_replace( '#[^a-zA-Z]#', '', $slug ) );
$output = "
<?php
/**
* Theme functions and definitions.
*/
function {$slug_no_hyphens}_child_enqueue_styles() {
wp_enqueue_style( '{$slug}-child-style',
get_stylesheet_directory_uri() . '/style.css');
}
add_action( 'wp_enqueue_scripts', '{$slug_no_hyphens}_child_enqueue_styles' );\n
";
// Let's remove the tabs so that it displays nicely.
$output = trim( preg_replace( '/\t+/', '', $output ) );
// Filterable return.
return $output;
}
add_filter( 'merlin_generate_child_functions_php', 'cursornt_merlin_generate_child_functions_php', 10, 2 );

add_filter( 'woocommerce_enable_setup_wizard', '__return_false' );
