<?php
/**
 * Initialize the custom Theme Options.
 */
add_action( 'init', 'proland_custom_theme_options' );
/**
 * Build the custom settings & update OptionTree.
 *
 * @return    void
 * @since     2.3.0
 */
function proland_custom_theme_options() {
  /* OptionTree is not loaded yet, or this is not an admin request */
  if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() )
    return false;
  /**
   * Get a copy of the saved settings array.
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  $custom_settings = array(
    'contextual_help' => array(
      'sidebar'       => ''
    ),
    'sections'        => array(
	array(
        'id'          => 'general',
        'title'       => 'General Config'
    ),
	array(
        'id'          => 'blogtab',
        'title'       => 'Blog & Page'
    ),
	array(
        'id'          => 'single_post',
        'title'       => 'Single Post'
    ),
	array(
        'id'          => 'archive_page',
        'title'       => 'Archive Page'
    ),
	array(
        'id'          => 'error_page',
        'title'       => '404 Page'
    ),
	array(
        'id'          => 'search_page',
        'title'       => 'Search Page'
    ),
	array(
        'id'          => 'sidebars',
        'title'       => 'Sidebars'
    ),
	array(
        'id'          => 'sidebars_settings',
        'title'       => 'Sidebars Colors'
    ),
	array(
        'id'          => 'copyright',
        'title'       => 'Footer'
    ),
	array(
		'id'          => 'woo',
		'title'       => 'Woocommerce'
	),
	array(
		'id'          => 'maps',
		'title'       => 'Google Maps API KEY'
	),
	array(
		'id'          => 'css',
		'title'       => 'Custom CSS'
	),
	array(
		'id'          => 'others',
		'title'       => 'Icon Libraries'
	),
  array(
    'id'  		    => 'google_fonts',
    'title' 	    => esc_html__('Google Fonts', 'proland' )
  ),
  array(
    'id'  		    => 'typography',
    'title' 	    => esc_html__('Typography', 'proland' )
  ),

), // sidebar end

// options start
'settings'        => array(

	array(
        'id'          => 'proland_line_v',
        'label'       => esc_html__( 'Line icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Line icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_awe_v',
        'label'       => esc_html__( 'Font awesome library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Line icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_vc_line_v',
        'label'       => esc_html__( 'Visual composer line icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Line icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_op_v',
        'label'       => esc_html__( 'Open Iconic icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Open icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_typ_v',
        'label'       => esc_html__( 'Typ Icon icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Typ icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_ent_v',
        'label'       => esc_html__( 'Entypo Icon icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Entypo icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_mono_v',
        'label'       => esc_html__( 'Mono Social Icon icon library', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Mono Social icon library upload page %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_animate',
        'label'       => esc_html__( 'Animation', 'proland' ),
        'desc'        => sprintf( esc_html__( 'You can control item animate,  %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'others',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'additionalcss',
        'label'       => 'additional css',
        'desc'        => 'You can add additional css ',
        'type'        => 'css',
        'section'     => 'css'
    ),
	array(
        'id'          => 'additional_1200_css',
        'label'       => 'Max width 1200px',
        'desc'        => 'You can add responsive css for max width 1200px',
        'type'        => 'css',
        'section'     => 'css'
    ),
	array(
        'id'          => 'additional_992_css',
        'label'       => 'Max width 992px',
        'desc'        => 'You can add responsive css for max width 992px',
        'type'        => 'css',
        'section'     => 'css'
    ),
	array(
        'id'          => 'additional_767_css',
        'label'       => 'Max width 767px',
        'desc'        => 'You can add responsive css for max width 767px',
        'type'        => 'css',
        'section'     => 'css'
    ),
	array(
        'id'          => 'additional_480_css',
        'label'       => 'Max width 480px',
        'desc'        => 'You can add responsive css for max width 480px',
        'type'        => 'css',
        'section'     => 'css'
    ),
	array(
        'id'          => 'proland_map_api_key',
        'label'       => 'Google Maps api key',
        'desc'        => 'You must create an api key and paste this box. Create :https://developers.google.com/maps/documentation/javascript/get-api-key#key ',
        'type'        => 'text',
        'section'     => 'maps'
    ),

	array(
        'id'          => 'woo_column',
        'label'       => esc_html__( 'Woocommerce Shop page column type', 'proland' ),
        'desc'        => esc_html__( 'You can change column number via this option', 'proland' ),
        'std'         => '4',
        'type'        => 'select',
        'section'     => 'woo',
        'operator'    => 'and',
        'choices'     => array(
            array(
                'value'       => '4',
                'label'       => esc_html__( 'default', 'proland' )
            ),
            array(
                'value'       => '3',
                'label'       => esc_html__( '3 column', 'proland' )
            ),
            array(
                'value'       => '2',
                'label'       => esc_html__( '2 column', 'proland' )
            ),
        )
	),
    array(
        'id'          => 'woo_per_page',
        'label'       => esc_html__( 'Woocommerce Shop post per page', 'proland' ),
        'desc'        => esc_html__( 'Use simple number.Default count 6.', 'proland' ),
        'type'        => 'text',
        'section'     => 'woo'
    ),



	array(
        'id'          => 'proland_frontpageheadbg',
        'label'       =>  esc_html__( 'Frontpage Header Section or video background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your image for parallax header or video background image', 'proland' ),
        'type'        => 'upload',
        'section'     => 'frontheader_bg',
		'operator'    => 'and'
    ),


	 array(
        'id'          => 'proland_video_format',
        'label'       => esc_html__( 'Video Format', 'proland' ),
        'desc'        => esc_html__( 'Please choose video type', 'proland' ),
        'std'         => 'mp4',
        'type'        => 'select',
        'section'     => 'frontheader_bg',
        'operator'    => 'and',
        'choices'     => array(
          array(
            'value'       => 'mp4',
            'label'       => esc_html__( 'MP4', 'proland' ),
            'src'         => ''
        ),
          array(
            'value'       => 'webm',
            'label'       => esc_html__( 'WEBM', 'proland' ),
            'src'         => ''
          )
        )
    ),
   array(
        'id'          => 'proland_video_mp4',
        'label'       => 'MP4 video source',
        'desc'        => 'Please enter MP4 format video source',
        'type'        => 'text',
        'section'     => 'frontheader_bg'
    ),
	array(
        'id'          => 'proland_video_webm',
        'label'       => 'WEBM video source',
        'desc'        => 'Please enter WEBM format video source',
        'type'        => 'text',
        'section'     => 'frontheader_bg'
	),


  /*** GENERAL SETTINGS. **/
    array(
        'id'          => 'generaltab1',
        'label'       => __( 'General', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),
	array(
		'id'          => 'proland_layout_type',
		'label'       => esc_html__('Layout Type', 'proland' ),
		'desc'        => esc_html__('Please choose layout type , Full Width or boxed', 'proland' ),
		'std'         => 'full',
		'type'        => 'select',
		'section'     => 'general',
		'operator'    => 'and',
		'choices'     => array(
			array(
				'value'       => 'full',
				'label'       => esc_html__('Full Width', 'proland' )
			),
			array(
				'value'       => 'boxed',
				'label'       => esc_html__('Boxed', 'proland' )
			)
		)
	),
	array(
		'id'          => 'proland_format_content_type',
		'label'       => esc_html__('Post format content type', 'proland' ),
		'desc'        => esc_html__('Please choose layout type , full or excerpt', 'proland' ),
		'std'         => 'full',
		'type'        => 'select',
		'section'     => 'general',
		'operator'    => 'and',
		'choices'     => array(
			array(
				'value'       => 'd',
				'label'       => esc_html__('Full Content', 'proland' )
			),
			array(
				'value'       => 'e',
				'label'       => esc_html__('Excerpt', 'proland' )
			)
		)
	),
    array(
        'id'          => 'generaltab2',
        'label'       => __( 'Header', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),
   	array(
        'id'          => 'proland_relative_header',
        'label'       => esc_html__( 'Header position type', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Header position fixed/on relative/off %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'operator'    => 'and'
	),
   	array(
        'id'          => 'proland_nonanimate_header',
        'label'       => esc_html__( 'Header disable animate after scroll', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Header animate %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'operator'    => 'and'
	),
    array(
        'id'          => 'generaltab3',
        'label'       => __( 'General Colors', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),
    array(
		'id'          => 'proland_theme_color_two',
		'label'       => esc_html__( 'Theme general color 1', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),

	array(
		'id'          => 'proland_theme_color_one',
		'label'       => esc_html__( 'Theme general color 2', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),

	array(
		'id'          => 'proland_theme_color_three',
		'label'       => esc_html__( 'Theme general color 3', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),

    array(
        'id'          => 'generaltab4',
        'label'       => __( 'Preloader', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),
    array(
        'id'          => 'proland_pre',
        'label'       => esc_html__( 'Preloader', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Preloader visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'operator'    => 'and'
    ),

	array(
        'id'          => 'custompre',
        'label'       =>  esc_html__( 'Custom preloader background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your  image', 'proland' ),
        'type'        => 'upload',
        'section'     => 'general',
		'operator'    => 'and'
    ),
    array(
      'id'          => 'proland_pre_type',
      'label'     => esc_html__('Preloader types', 'proland' ),
      'desc'      => esc_html__('Please choose a preloader type', 'proland' ),
      'std'       => 'default',
      'type'      => 'select',
      'section'   => 'general',
      'condition' => 'proland_pre:is(on)',
      'operator'  => 'and',
      'choices'   => array(
      array(
        'value' => 'default',
        'label' => esc_html__('Default', 'proland' ),
      ),
      array(
        'value' => '01',
        'label' => esc_html__('Type 1', 'proland' ),
      ),
      array(
        'value' => '02',
        'label' => esc_html__('Type 2', 'proland' ),
      ),
      array(
        'value' => '03',
        'label' => esc_html__('Type 3', 'proland' ),
      ),
      array(
        'value' => '04',
        'label' => esc_html__('Type 4', 'proland' ),
      ),
      array(
        'value' => '05',
        'label' => esc_html__('Type 5', 'proland' ),
      ),
      array(
        'value' => '06',
        'label' => esc_html__('Type 6', 'proland' ),
      ),
      )
    ),
    array(
  		'id'          => 'proland_pretextcolor',
  		'label'       => esc_html__( 'Preloader text and spinner color ', 'proland' ),
  		'desc'        => esc_html__( 'Please select color', 'proland' ),
  		'type'        => 'colorpicker',
      'condition' => 'proland_pre_type:not(default)',
  		'section'     => 'general'
  	),
  	array(
  		'id'          => 'proland_prebgt',
  		'label'       => esc_html__( 'Preloader background color ', 'proland' ),
  		'desc'        => esc_html__( 'Please select color', 'proland' ),
  		'type'        => 'colorpicker',
      'condition' => 'proland_pre_type:not(default)',
  		'section'     => 'general'
  	),


    /**
    * NAVIGATION SETTINGS.
    */

    array(
    'id'          => 'generaltab5',
    'label'       => __( 'Menu Options', 'proland' ),
    'type'        => 'tab',
    'section'     => 'general'
    ),


    array(
    'id'          => 'proland_navigation_item_fs',
    'label'       => esc_html__('Navigation item font-size', 'proland' ),
    'desc'        => esc_html__('Navigation item font-size', 'proland' ),
    'type'        => 'numeric-slider',
    'min_max_step'=> '0,100',
    'section'     => 'general',
    'operator'    => 'and'
    ),
    array(
      'id'          => 'proland_navigation_transform',
      'label'     => esc_html__('Navigation item text transform', 'proland' ),
      'desc'      => esc_html__('Navigation item text transform', 'proland' ),
      'std'       => 'default',
      'type'      => 'select',
      'section'   => 'general',
      'condition' => 'proland_pre:is(on)',
      'operator'  => 'and',
      'choices'   => array(
      array(
        'value' => 'uppercase',
        'label' => esc_html__('Uppercase', 'proland' ),
      ),
      array(
        'value' => 'capitalize',
        'label' => esc_html__('Capitalize', 'proland' ),
      ),
      array(
        'value' => 'lowercase',
        'label' => esc_html__('lowercase', 'proland' ),
      ),
      )
    ),
    array(
    'id'          => 'proland_navigationbg',
    'label'       => esc_html__( 'Theme navigation background color ', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),
    array(
    'id'          => 'proland_navitem',
    'label'       => esc_html__( 'Theme navigation menu item color', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),
    array(
    'id'          => 'proland_navitemhover',
    'label'       => esc_html__( 'Theme navigation menu item hover color', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),
    //sticky header
    array(
    'id'          => 'proland_sticky_navigationbg',
    'label'       => esc_html__( 'Theme navigation sticky background color ', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),
    array(
    'id'          => 'proland_sticky_navitem',
    'label'       => esc_html__( 'Theme navigation sticky menu item color', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),
    array(
    'id'          => 'proland_sticky_navitemhover',
    'label'       => esc_html__( 'Theme navigation sticky menu item hover color', 'proland' ),
    'desc'        => esc_html__( 'Please select color', 'proland' ),
    'type'        => 'colorpicker',
    'section'     => 'general'
    ),

    array(
        'id'          => 'generaltab6',
        'label'       => __( 'Menu Buttons', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),


       array(
            'id'          => 'proland_header_menu_button_url',
            'label'       => esc_html__( 'Pages header button url', 'proland' ),
            'desc'        => sprintf( esc_html__( 'If you want to hide button leave blank this textbox.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
            'type'        => 'text',
            'section'     => 'general'
    	),
       array(
            'id'          => 'proland_header_menu_button_url_text',
            'label'       => esc_html__( 'Pages header button url text', 'proland' ),
            'desc'        => sprintf( esc_html__( 'Button text', 'proland' ), '<code>on</code>', '<code>off</code>' ),
            'type'        => 'text',
            'section'     => 'general'
    	),
      array(
        'id'          => 'proland_header_menu_button_url_target',
        'label'       => esc_html__('Pages header button target', 'proland' ),
        'desc'        => esc_html__('Pages header button target', 'proland' ),
        'type'        => 'select',
        'section'     => 'general',
        'operator'    => 'and',
        'choices'     => array(
          array(
            'value'       => '_target',
            'label'       => esc_html__('Target', 'proland' ),
            'src'         => ''
          ),
          array(
            'value'       => '_self',
            'label'       => esc_html__('Self', 'proland' ),
            'src'         => ''
          ),
          array(
            'value'       => '_parent',
            'label'       => esc_html__('Parent', 'proland' ),
            'src'         => ''
          ),
          array(
            'value'       => '_top',
            'label'       => esc_html__('Top', 'proland' ),
            'src'         => ''
          ),
        )
      ),
    	array(
            'id'          => 'proland_header_menu_cart_btn',
            'label'       => esc_html__( 'Pages header woocommerce cart button visibility', 'proland' ),
            'desc'        => sprintf( esc_html__( 'Cart button visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
            'std'         => 'on',
            'type'        => 'on-off',
            'section'     => 'general',
            'operator'    => 'and'
    	),
        array(
            'id'          => 'generaltab7',
            'label'       => __( 'Logo', 'proland' ),
            'type'        => 'tab',
            'section'     => 'general'
        ),
        array(
            'id'          => 'proland_logo_type',
            'label'       => esc_html__('Logo Type', 'proland' ),
            'desc'        => esc_html__('Please choose logo type', 'proland' ),
            'std'         => 'img',
            'type'        => 'select',
            'section'     => 'general',
            'operator'    => 'and',
            'choices'     => array(
            array(
                'value'       => 'img',
                'label'       => esc_html__('Image Logo', 'proland' ),
                'src'         => ''
              ),
            array(
                'value'       => 'text',
                'label'       => esc_html__('Text Logo', 'proland' ),
                'src'         => ''
              )
            )
        ),
	array(
        'id'          => 'proland_logoimg',
        'label'       => 'Upload logo image',
        'desc'        => 'Upload logo image',
        'type'        => 'upload',
        'section'     => 'general'
	),
   array(
        'id'          => 'proland_sticky_logoimg',
        'label'       => 'Upload sticky logo image',
        'desc'        => 'Upload sticky logo image',
        'type'        => 'upload',
        'section'     => 'general'
	),
	array(
        'id'          => 'proland_logowidth',
        'label'       => esc_html__('Logo image width', 'proland' ),
        'desc'        => esc_html__('Blog Pages width', 'proland' ),
        'std'         => '203',
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,1000',
        'section'     => 'general',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_logoheight',
        'label'       => esc_html__('Logo image height', 'proland' ),
        'desc'        => esc_html__('Blog Pages height', 'proland' ),
        'std'         => '55',
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,1000',
        'section'     => 'logo',
		'operator'    => 'and'
	),
	array(
		'id'          => 'proland_padding_logo',
		'label'       => esc_html__( 'Logo padding', 'proland' ),
		'desc'        => esc_html__( 'Logo padding', 'proland' ),
		'type'        => 'spacing',
		'section'     => 'general',
	),
	array(
		'id'          => 'proland_margin_logo',
		'label'       => esc_html__( 'Logo margin', 'proland' ),
		'desc'        => esc_html__( 'Logo margin', 'proland' ),
		'type'        => 'spacing',
		'section'     => 'general',
	),
	array(
		'id'          => 'proland_padding_logo_sticky',
		'label'       => esc_html__( 'Sticky Logo padding', 'proland' ),
		'desc'        => esc_html__( 'Sticky Logo padding', 'proland' ),
		'type'        => 'spacing',
		'section'     => 'general',
	),
	array(
		'id'          => 'proland_margin_logo_sticky',
		'label'       => esc_html__( 'Sticky Logo margin', 'proland' ),
		'desc'        => esc_html__( 'Sticky Logo margin', 'proland' ),
		'type'        => 'spacing',
		'section'     => 'general',
	),
	array(
        'id'          => 'proland_logo_shrink_w',
        'label'       => esc_html__('Logo image shrink/scroll after width', 'proland' ),
        'desc'        => esc_html__('Logo image shrink/scroll after width', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,1000',
		'std'		  => '155',
        'section'     => 'general',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_logo_shrink_h',
        'label'       => esc_html__('Logo image shrink/scroll after height', 'proland' ),
        'desc'        => esc_html__('Logo image shrink/scroll after height', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,1000',
		'std'		  => '40',
        'section'     => 'general',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_textlogo',
        'label'       => 'Text logo',
        'desc'        => 'Text logo',
        'std'         => 'proland',
        'type'        => 'text',
        'section'     => 'general'
    ),

    array(
        'id'          => 'generaltab8',
        'label'       => __( 'Breadcrumbs', 'proland' ),
        'type'        => 'tab',
        'section'     => 'general'
    ),

    array(
        'id'          => 'proland_breadcrubms_visibility',
        'label'       => esc_html__( 'Breadcrubms visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Breadcrubms visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'operator'    => 'and'
    ),

	array(
		'id'          => 'proland_blogbreadcrubmscolor',
		'label'       => esc_html__( 'Blog Pages Breadcrubms color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),
	array(
		'id'          => 'proland_blogbreadcrubmshovercolor',
		'label'       => esc_html__( 'Blog Pages Breadcrubms hover color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),
	array(
		'id'          => 'proland_blogbreadcrubmscurrentcolor',
		'label'       => esc_html__( 'Blog Pages Breadcrubms current page text color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'general'
	),
	array(
        'id'          => 'proland_blogbreadcrubmsfontsize',
        'label'       => esc_html__('Breadcrubms font size', 'proland' ),
        'desc'        => esc_html__('Blog/Pages Header Breadcrubms font size', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'general',
		'operator'    => 'and'
	),

 /**
   * SIDEBAR TYPE SETTINGS.
   */
		 array(
        'id'          => 'proland_bloglayout',
        'label'       => esc_html__( 'Blog Layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose blog page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_pagelayout',
        'label'       => esc_html__( 'Default Page Layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose default page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_searchlayout',
        'label'       => esc_html__( 'Search page Layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose search page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_postlayout',
        'label'       => esc_html__( 'Blog single page layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose post page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_archivelayout',
        'label'       => esc_html__( 'archive page layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose archive page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_404layout',
        'label'       => esc_html__( '404 page layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose 404 page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
	),

	array(
        'id'          => 'woosingle',
        'label'       => esc_html__( 'Woocommerce single page layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose Woocommerce single page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
    ),
	   array(
        'id'          => 'woopage',
        'label'       => esc_html__( 'Woocommerce  page layout', 'proland' ),
        'desc'        => esc_html__( 'Please choose 404 page layout type', 'proland' ),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'sidebars',
        'operator'    => 'and'
    ),


 /**
   * SIDEBAR SETTINGS.
   */
      array(
        'id'          => 'proland_sidebarwidgetareabgcolor',
        'label'       => esc_html__('Theme Sidebar widget area background color', 'proland' ),
        'desc'        => esc_html__('Please select color', 'proland' ),
        'type'        => 'colorpicker-opacity',
        'section'     => 'sidebars_settings',
        'operator'    => 'and'
    ),
	    array(
			'id'          => 'proland_sidebarwidgetareabgcolor',
			'label'       => esc_html__( 'Theme Sidebar widget area background color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
			'section'     => 'sidebars_settings'
		),
	    array(
			'id'          => 'proland_sidebarwidgetgeneralcolor',
			'label'       => esc_html__( 'Theme Sidebar widget general color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
			'section'     => 'sidebars_settings'
		),
		array(
			'id'          => 'proland_sidebarwidgettitlecolor',
			'label'       => esc_html__( 'Theme Sidebar widget title color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
				'section'     => 'sidebars_settings'
		),
 		array(
			'id'          => 'proland_sidebarlinkcolor',
			'label'       => esc_html__( 'Theme Sidebar link title color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
				'section'     => 'sidebars_settings'
		),
 		array(
			'id'          => 'proland_sidebarlinkhovercolor',
			'label'       => esc_html__( 'Theme Sidebar link title hover color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
				'section'     => 'sidebars_settings'
		),
  		array(
			'id'          => 'proland_sidebarsearchsubmittextcolor',
			'label'       => esc_html__( 'Theme Sidebar search submit text color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
				'section'     => 'sidebars_settings'
		),
      	array(
			'id'          => 'proland_sidebarsearchsubmitbgcolor',
			'label'       => esc_html__( 'Theme Sidebar search submit background color', 'proland' ),
			'desc'        => esc_html__( 'Please select color', 'proland' ),
			'type'        => 'colorpicker',
				'section'     => 'sidebars_settings'
		),



  /**
   * BLOG/PAGE HEADER SETTINGS.
   */

    array(
       'id'          => 'blogtab1',
       'label'       => esc_html__( 'Blog Options', 'proland' ),
       'type'        => 'tab',
       'section'     => 'blogtab'
    ),

	array(
        'id'          => 'proland_mask_c_page_header',
        'label'       => esc_html__( 'Pages header background image visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Heading visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blogtab',
        'operator'    => 'and'
	),
	array(
        'id'          => 'proland_otherpageheadbg',
        'label'       =>  esc_html__( 'Blog Pages Header Section background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your image for parallax header', 'proland' ),
        'type'        => 'upload',
        'section'     => 'blogtab',
		'operator'    => 'and'
    ),
	array(
		'id'          => 'proland_blogheaderbgcolor',
		'label'       => esc_html__( 'Blog Pages Header Section background color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker-opacity',
		'section'     => 'blogtab'
	),
	array(
        'id'          => 'proland_blogheaderbgheight',
        'label'       => esc_html__('Blog Pages Header height', 'proland' ),
        'desc'        => esc_html__('Blog Pages Header height', 'proland' ),
        'type'        => 'numeric-slider',
		'std'         => '26',
		'min_max_step'=> '0,100',
        'section'     => 'blogtab',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_blogheaderpaddingtop',
        'label'       => esc_html__('Header padding top', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '150',
        'section'     => 'blogtab',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_blogheaderpaddingbottom',
        'label'       => esc_html__('Header padding bottom', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '50',
        'section'     => 'blogtab',
		'operator'    => 'and'
	),
    array(
        'id'          => 'blogtab2',
        'label'       => esc_html__( 'Blog Heading Colors', 'proland' ),
        'type'        => 'tab',
        'section'     => 'blogtab'
    ),


	array(
		'id'          => 'proland_blogheadingcolor',
		'label'       => esc_html__( 'Blog Pages Heading color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'blogtab'
	),
	array(
		'id'          => 'proland_blogsubtitlecolor',
		'label'       => esc_html__( 'Blog Pages Subtitle color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'blogtab'
	),


    /**
      * POST SETTINGS.
      */


            array(
        		'id'          => 'nt_honshi_post_tab',
        		'label'       => esc_html__( 'Post Options', 'proland' ),
        		'type'        => 'tab',
        		'section'     => 'single_post'
        	),
        	array(
                'id'          => 'proland_content_social',
                'label'       => esc_html__( 'Blog post content left social dropdown visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Social dropdown visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_facebook',
                'label'       => esc_html__( 'Facebook share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown facebook share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_twitter',
                'label'       => esc_html__( 'Twitter share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown twitter share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_google',
                'label'       => esc_html__( 'Google plus share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown google-plus share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_digg',
                'label'       => esc_html__( 'Digg plus share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown digg share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_reddit',
                'label'       => esc_html__( 'Reddit plus share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown reddit share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_content_pinterest',
                'label'       => esc_html__( 'Pinterest plus share icon visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content left social dropdown pinterest share icon visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'condition'   => 'proland_content_social:is(on)',
                'operator'    => 'and'
            ),
        	array(
                'id'          => 'proland_content_comment',
                'label'       => esc_html__( 'Blog post content box left comment  visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Left comment  visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
        	array(
                'id'          => 'proland_content_like',
                'label'       => esc_html__( 'Blog post content left like button visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Left like button visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_bottom_social',
                'label'       => esc_html__( 'Blog post content bottom social media visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post content bottom social visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_single_comment_disable',
                'label'       => esc_html__( 'Single pages comment area visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Please select single pages comment area visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
            array(
                'id'          => 'proland_post_general_tab',
                'label'       => esc_html__( 'Read More Button', 'proland' ),
                'type'        => 'tab',
                'section'     => 'single_post'
              ),
              array(
                'id'          => 'proland_readm_display',
                'label'       => esc_html__( 'Blog post read more button display', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Blog post readm more button display %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
              ),
              array(
        			'id'          => 'proland_readm_title',
        			'label'       => esc_html__('Blog post read more button title', 'proland' ),
        			'desc'        => esc_html__('Blog post read more button title.', 'proland' ),
        			'type'        => 'text',
        			'condition'   => 'proland_readm_display:is(on)',
        			'section'     => 'single_post'
        		),
            array(
          		'id'          => 'proland_readm_t_c',
          		'label'       => esc_html__( 'Blog post read more button text color', 'proland' ),
          		'desc'        => esc_html__( 'Please select color', 'proland' ),
          		'type'        => 'colorpicker',
          		'section'     => 'single_post'
          	),
            array(
          		'id'          => 'proland_readm_bg_c',
          		'label'       => esc_html__( 'Blog post read more button bg color', 'proland' ),
          		'desc'        => esc_html__( 'Please select color', 'proland' ),
          		'type'        => 'colorpicker',
          		'section'     => 'single_post'
          	),
            array(
          		'id'          => 'proland_readm_ht_c',
          		'label'       => esc_html__( 'Blog post read more button hover text color', 'proland' ),
          		'desc'        => esc_html__( 'Please select color', 'proland' ),
          		'type'        => 'colorpicker',
          		'section'     => 'single_post'
          	),
            array(
          		'id'          => 'proland_readm_hbg_c',
          		'label'       => esc_html__( 'Blog post read more button hover bg color', 'proland' ),
          		'desc'        => esc_html__( 'Please select color', 'proland' ),
          		'type'        => 'colorpicker',
          		'section'     => 'single_post'
          	),

          array(
              'id'          => 'posttab2',
              'label'       => __( 'Single Post Header', 'proland' ),
              'type'        => 'tab',
              'section'     => 'single_post'
          ),

          /**
           * SINGLE HEADER SETTINGS.
           */
        	array(
                'id'          => 'proland_singlepageheadbg',
                'label'       =>  esc_html__( 'Single Header Section background image', 'proland' ),
                'desc'        =>  esc_html__( 'You can upload your image for parallax header', 'proland' ),
                'type'        => 'upload',
                'section'     => 'single_post',
        		'operator'    => 'and'
            ),

        	array(
        		'id'          => 'proland_singleheaderbgcolor',
        		'label'       => esc_html__( 'Single Pages Header Section background color ', 'proland' ),
        		'desc'        => esc_html__( 'Please select color', 'proland' ),
        		'type'        => 'colorpicker',
        		'section'     => 'single_post'
        	),

           	array(
                'id'          => 'proland_single_disable_heading',
                'label'       => esc_html__( 'Single pages heading post title visibility', 'proland' ),
                'desc'        => sprintf( esc_html__( 'Please select single pages heading post title  visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
                'std'         => 'on',
                'type'        => 'on-off',
                'section'     => 'single_post',
                'operator'    => 'and'
            ),
        	array(
                'id'          => 'proland_singleheaderbgheight',
                'label'       => esc_html__('Single Pages Header height', 'proland' ),
                'desc'        => esc_html__('Single Pages Header height', 'proland' ),
                'type'        => 'numeric-slider',
        		'std'         => '26',
        		'min_max_step'=> '0,100',
                'section'     => 'single_post',
        		'operator'    => 'and'
        	),
        	array(
                'id'          => 'proland_singleheaderpaddingtop',
                'label'       => esc_html__('Header padding top', 'proland' ),
                'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
                'type'        => 'numeric-slider',
        		'min_max_step'=> '0,500',
        		'std'         => '150',
                'section'     => 'single_post',
        		'operator'    => 'and'
        	),
        	array(
                'id'          => 'proland_singleheaderpaddingbottom',
                'label'       => esc_html__('Header padding bottom', 'proland' ),
                'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
                'type'        => 'numeric-slider',
        		'min_max_step'=> '0,500',
        		'std'         => '50',
                'section'     => 'single_post',
        		'operator'    => 'and'
        	),
        	array(
        		'id'          => 'proland_singleheadingcolor',
        		'label'       => esc_html__( 'Single Pages Heading color ', 'proland' ),
        		'desc'        => esc_html__( 'Please select color', 'proland' ),
        		'type'        => 'colorpicker',
        		'section'     => 'single_post'
        	),
        	array(
                'id'          => 'proland_single_heading_fontsize',
                'label'       => esc_html__('Single Heading font size', 'proland' ),
                'std'        => '',
                'type'        => 'numeric-slider',
        		'min_max_step'=> '0,100',
                'section'     => 'single_post',
        		'operator'    => 'and'
        	),

          array(
              'id'          => 'proland_single_disable_bred',
              'label'       => esc_html__( 'Single pages display breadcrubms', 'proland' ),
              'desc'        => sprintf( esc_html__( 'Please select single pages disable breadcrubms %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
              'std'         => 'on',
              'type'        => 'on-off',
              'section'     => 'single_post',
              'operator'    => 'and'
          ),

          array(
              'id'          => 'posttab3',
              'label'       => __( 'Single Post Colors', 'proland' ),
              'type'        => 'tab',
              'section'     => 'single_post'
          ),

           array(
               'id'          => 'proland_blogposttitlecolor',
               'label'       => esc_html__( 'Blog Post Title color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogposttitlhoverecolor',
               'label'       => esc_html__( 'Blog Post Title hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogmetacolor',
               'label'       => esc_html__( 'Blog Post Meta Title color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogmetalinktextcolor',
               'label'       => esc_html__( 'Blog Post Meta Link Text color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogmetalinkhovercolor',
               'label'       => esc_html__( 'Blog Post Meta Link Text hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogmetalinktextbgcolor',
               'label'       => esc_html__( 'Blog Post Meta Link Text background color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogmetalinktextbghovercolor',
               'label'       => esc_html__( 'Blog Post Meta Link Text background hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogpostparagraphcolor',
               'label'       => esc_html__( 'Blog Post Paragraph color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogpostbuttonbgcolor',
               'label'       => esc_html__( 'Blog Post button background color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogpostbuttonbghovercolor',
               'label'       => esc_html__( 'Blog Post button background hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogpostbuttontitlecolor',
               'label'       => esc_html__( 'Blog Post button title color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogpostbuttontitlehovercolor',
               'label'       => esc_html__( 'Blog Post button title hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),

           array(
               'id'          => 'proland_blogsharebgcolor',
               'label'       => esc_html__( 'Blog Post Share Icon background color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogsharebghovercolor',
               'label'       => esc_html__( 'Blog Post Share Icon background hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogsharecolor',
               'label'       => esc_html__( 'Blog Post Share Icon color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogsharehovercolor',
               'label'       => esc_html__( 'Blog Post Share Icon hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),

           array(
               'id'          => 'proland_blogcommentformsubmitcolor',
               'label'       => esc_html__( 'Single post comment button title color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogcommentformsubmithovercolor',
               'label'       => esc_html__( 'Single post comment button title hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogcommentformsubmitbgcolor',
               'label'       => esc_html__( 'Single post comment button background color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_blogcommentformsubmitbghovercolor',
               'label'       => esc_html__( 'Single post comment button background hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_pagertitlecolor',
               'label'       => esc_html__( 'Pager button title color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_pagertitlehovercolor',
               'label'       => esc_html__( 'Pager button title hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_pagerbgcolor',
               'label'       => esc_html__( 'Pager button background color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),
           array(
               'id'          => 'proland_pagerbghovercolor',
               'label'       => esc_html__( 'Pager button background hover color', 'proland' ),
               'desc'        => esc_html__( 'Please select color', 'proland' ),
               'type'        => 'colorpicker',
                   'section'     => 'single_post'
           ),



  /**
   * ARCHIVE HEADER SETTINGS.
   */
	array(
        'id'          => 'proland_archivepageheadbg',
        'label'       =>  esc_html__( 'Archive Header Section background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your image for parallax header', 'proland' ),
        'type'        => 'upload',
        'section'     => 'archive_page',
		'operator'    => 'and'
    ),

	array(
		'id'          => 'proland_archiveheaderbgcolor',
		'label'       => esc_html__( 'Archive Pages Header Section background color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'archive_page'
	),

	array(
        'id'          => 'proland_archiveheaderbgheight',
        'label'       => esc_html__('Archive Pages Header height', 'proland' ),
        'desc'        => esc_html__('Archive Pages Header height', 'proland' ),
        'type'        => 'numeric-slider',
		'std'         => '26',
		'min_max_step'=> '0,100',
        'section'     => 'archive_page',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_archiveheaderpaddingtop',
        'label'       => esc_html__('Header padding top', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '150',
        'section'     => 'archive_page',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_archiveheaderpaddingbottom',
        'label'       => esc_html__('Header padding bottom', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '10',
        'section'     => 'archive_page',
		'operator'    => 'and'
	),


	array(
        'id'          => 'proland_archive_heading_visibility',
        'label'       => esc_html__( 'Archive Heading visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Archive Heading visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'archive_page',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_archive_heading',
        'label'       => esc_html__( 'Archive Heading', 'proland' ),
        'desc'        => esc_html__( 'Enter Archive Heading', 'proland' ),
        'std'         => 'Our Archive',
        'type'        => 'text',
        'section'     => 'archive_page',
    ),
	array(
        'id'          => 'proland_archive_heading_fontsize',
        'label'       => esc_html__('Archive Heading font size', 'proland' ),
        'desc'        => esc_html__('Enter Archive Heading font size', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'archive_page',
		'operator'    => 'and'
	),

	array(
		'id'          => 'proland_archiveheadingcolor',
		'label'       => esc_html__( 'Archive Pages Heading color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'archive_page'
	),

	array(
        'id'          => 'proland_archive_slogan_visibility',
        'label'       => esc_html__( 'Archive Heading visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Archive slogan visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'archive_page',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_archive_slogan',
        'label'       => esc_html__( 'Archive Slogan', 'proland' ),
        'desc'        => esc_html__( 'Enter Archive Slogan', 'proland' ),
        'std'         => 'Welcome to your Archive. This is your all post. Edit or delete them, then start writing!',
        'type'        => 'text',
        'section'     => 'archive_page',
        'class'       => ''
    ),
	array(
		'id'          => 'proland_archiveheaderparagraphcolor',
		'label'       => esc_html__( 'Archive Pages paragraph/slogan color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'archive_page'
	),



  /**
   * 404 PAGE HEADER SETTINGS.
   */
	array(
        'id'          => 'proland_errorpageheadbg',
        'label'       =>  esc_html__( '404 Header Section background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your image for parallax header', 'proland' ),
        'type'        => 'upload',
        'section'     => 'error_page',
		'operator'    => 'and'
    ),

	array(
		'id'          => 'proland_errorheaderbgcolor',
		'label'       => esc_html__( '404 Pages Header Section background color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'error_page'
	),

	array(
        'id'          => 'proland_errorheaderbgheight',
        'label'       => esc_html__('404 Pages Header height', 'proland' ),
        'desc'        => esc_html__('404 Pages Header height', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
		'std'         => '26',
        'section'     => 'error_page',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_errorheaderpaddingtop',
        'label'       => esc_html__('Header padding top', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '150',
        'section'     => 'error_page',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_errorheaderpaddingbottom',
        'label'       => esc_html__('Header padding bottom', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '50',
        'section'     => 'error_page',
		'operator'    => 'and'
	),

	array(
        'id'          => 'proland_error_heading_visibility',
        'label'       => esc_html__( '404 Page Heading visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'error Heading visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'error_page',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_error_heading',
        'label'       => esc_html__( '404 Page Heading', 'proland' ),
        'desc'        => esc_html__( 'Enter Error Heading', 'proland' ),
        'std'         => '404 Page',
        'type'        => 'text',
        'section'     => 'error_page'
    ),
	array(
        'id'          => 'proland_error_heading_fontsize',
        'label'       => esc_html__('404 Page Heading font size', 'proland' ),
        'desc'        => esc_html__('Enter 404 Page Heading font size', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'error_page',
		'operator'    => 'and'
	),
	array(
		'id'          => 'proland_errorheadingcolor',
		'label'       => esc_html__( '404 Pages Heading color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'error_page'
	),


	array(
        'id'          => 'proland_error_slogan_visibility',
        'label'       => esc_html__( '404 Page slogan visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( '404 Page slogan visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'error_page',
        'operator'    => 'and'
    ),
	array(
        'id'          => 'proland_error_slogan',
        'label'       => esc_html__( '404 Page Slogan', 'proland' ),
        'desc'        => esc_html__( 'Enter 404 Page Slogan', 'proland' ),
        'std'         => 'Oops! That page can not be found.',
        'type'        => 'text',
        'section'     => 'error_page',
        'class'       => ''
    ),
	array(
		'id'          => 'proland_errorheaderparagraphcolor',
		'label'       => esc_html__( '404 Pages paragraph/slogan color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'error_page'
	),



  /**
   * SEARCH PAGE HEADER SETTINGS.
   */
	array(
        'id'          => 'proland_searchpageheadbg',
        'label'       =>  esc_html__( 'Search Header Section background image', 'proland' ),
        'desc'        =>  esc_html__( 'You can upload your image for parallax header', 'proland' ),
        'type'        => 'upload',
        'section'     => 'search_page'
    ),

	array(
		'id'          => 'proland_searchheaderbgcolor',
		'label'       => esc_html__( 'Search Pages Header Section background color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'search_page'
	),

	array(
        'id'          => 'proland_searchheaderbgheight',
        'label'       => esc_html__('Search Pages Header height', 'proland' ),
        'desc'        => esc_html__('Search Pages Header height', 'proland' ),
		'min_max_step'=> '0,100',
		'type'        => 'numeric-slider',
		'std'         => '26',
        'section'     => 'search_page'
	),
	array(
        'id'          => 'proland_searchheaderpaddingtop',
        'label'       => esc_html__('Header padding top', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '150',
        'section'     => 'search_page'
	),
	array(
        'id'          => 'proland_searchheaderpaddingbottom',
        'label'       => esc_html__('Header padding bottom', 'proland' ),
        'desc'        => esc_html__('You can use this option for heading text vertical align', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,500',
		'std'         => '50',
        'section'     => 'search_page'
	),

	array(
        'id'          => 'proland_search_heading_visibility',
        'label'       => esc_html__( 'Search Page Heading visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'search Heading visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'search_page'
    ),
	array(
        'id'          => 'proland_search_heading',
        'label'       => esc_html__( 'Search Page Heading', 'proland' ),
        'desc'        => esc_html__( 'Enter Search Heading', 'proland' ),
        'std'         => 'Search Page',
        'type'        => 'text',
        'section'     => 'search_page'
    ),
	array(
        'id'          => 'proland_search_heading_fontsize',
        'label'       => esc_html__('Search Page Heading font size', 'proland' ),
        'desc'        => esc_html__('Enter Search Page Heading font size', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'search_page'
	),
	array(
		'id'          => 'proland_searchheadingcolor',
		'label'       => esc_html__( 'Search Pages Heading color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'search_page'
	),


	array(
        'id'          => 'proland_search_slogan_visibility',
        'label'       => esc_html__( 'Search Page slogan visibility', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Search Page slogan visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'search_page'
    ),
	array(
        'id'          => 'proland_search_slogan',
        'label'       => esc_html__( 'Search Page Slogan', 'proland' ),
        'desc'        => esc_html__( 'Enter Search Page Slogan', 'proland' ),
        'std'         => 'Search completed',
        'type'        => 'text',
        'section'     => 'search_page'
    ),
	array(
		'id'          => 'proland_searchheaderparagraphcolor',
		'label'       => esc_html__( 'Search Pages paragraph/slogan color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'search_page'
	),



  /**
   * FOOTER SETTINGS.
   */

    array(
        'id'          => 'footertab1',
        'label'       => __( 'Footer', 'proland' ),
        'type'        => 'tab',
        'section'     => 'copyright'
    ),
	array(
        'id'          => 'proland_top_footerwd',
        'label'       => esc_html__( 'footer top widgetize area section', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Please choose footer  section %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'copyright',
        'operator'    => 'and'
    ),

	array(
		'id'          => 'proland_powered_display',
        'label'       => esc_html__( 'footer copyright section', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Please choose footer copyright section %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'copyright',
        'operator'    => 'and'
    ),


	array(
        'id'          => 'proland_footerpowered',
        'label'       => 'Footer copyright',
        'desc'        => 'Footer copyright text',
        'std'         => 'Launch beautiful, responsive websites faster with themes. Design By Ninetheme',
        'type'        => 'text',
        'section'     => 'copyright'
    ),


	   array(
        'id'          => 'proland_social_section',
        'label'       => esc_html__( 'social section visibility ', 'proland' ),
        'desc'        => sprintf( esc_html__( 'Please choose social section visibility %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'copyright',
        'operator'    => 'and'
    ),

	array(
        'id'          => 'proland_social',
        'label'       => 'Footer Social Icons',
        'desc'        => 'Footer Social Icons',
        'type'        => 'list-item',
        'section'     => 'copyright',
        'settings'    => array(
          array(
            'id'          => 'proland_social_text',
            'label'       => 'social icon name',
            'desc'        => 'Enter font awesome social icon name',
            'type'        => 'text'
        ),
          array(
            'id'          => 'proland_social_link',
            'label'       => 'Link',
            'desc'        => 'Enter font awesome social share link',
            'type'        => 'text'
          )
        )
    ),


	array(
        'id'          => 'proland_social_target',
        'label'       => esc_html__( 'Target social media', 'proland' ),
        'desc'        => esc_html__( 'Select social media target type. Default : _blank' , 'proland' ),
        'std'         => '_blank',
        'type'        => 'select',
        'section'     => 'copyright',
        'operator'    => 'and',
        'choices'     => array(
          array(
            'value'       => '_blank',
            'label'       => esc_html__( '_blank', 'proland' )
        ),
          array(
            'value'       => '_self',
            'label'       => esc_html__( '_self', 'proland' )
        ),
          array(
            'value'       => '_parent',
            'label'       => esc_html__( '_parent', 'proland' )
        ),
          array(
            'value'       => '_top',
            'label'       => esc_html__( '_top', 'proland' )
        ),
        )
	),
	array(
        'id'          => 'proland_social_fontsize',
        'label'       => esc_html__('Social font size', 'proland' ),
        'desc'        => esc_html__('Footer social font size', 'proland' ),
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'copyright',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_social_margin_left',
        'label'       => esc_html__('Social margin-left', 'proland' ),
        'desc'        => esc_html__('Footer social margin-left', 'proland' ),
        'std'         => '10',
        'type'        => 'numeric-slider',
		'min_max_step'=> '0,100',
        'section'     => 'copyright',
		'operator'    => 'and'
	),
	array(
        'id'          => 'proland_social_opacity',
        'label'       => 'Social opacity',
        'desc'        => 'Minimum 0 Maximum 1 default : 0.7 format : 0.x',
        'std'         => '0.7',
        'type'        => 'text',
        'section'     => 'copyright'
    ),


     array(
         'id'          => 'footertab2',
         'label'       => __( 'Footer Links', 'proland' ),
         'type'        => 'tab',
         'section'     => 'copyright'
     ),

 	array(
         'id'          => 'proland_link_section',
         'label'       => esc_html__( 'footer links area section', 'proland' ),
         'desc'        => sprintf( esc_html__( 'Please choose footer links section %s or %s.', 'proland' ), '<code>on</code>', '<code>off</code>' ),
         'std'         => 'on',
         'type'        => 'on-off',
         'section'     => 'copyright',
         'operator'    => 'and'
     ),

 	array(
         'id'          => 'proland_footer_link',
         'label'       => 'Footer links',
         'desc'        => 'Footer links',
         'type'        => 'list-item',
         'section'     => 'copyright',
         'settings'    => array(
           array(
             'id'          => 'proland_footer_link_text',
             'label'       => 'Link text',
             'desc'        => 'Enter link text',
             'type'        => 'text'
         ),
 		array(
             'id'          => 'proland_footer_link_url',
             'label'       => 'Link',
             'desc'        => 'Enter link / url',
 			'type'        => 'text'
 		),
 		array(
             'id'          => 'proland_link_target',
             'label'       => 'Target',
             'desc'        => 'Enter target type. _blank , _parent and more',
 			'type'        => 'text'
 		)
         )
     ),

  /**
   * FOOTER COLOR SETTINGS.
   */

   array(
       'id'          => 'footertab3',
       'label'       => __( 'Footer Colors', 'proland' ),
       'type'        => 'tab',
       'section'     => 'copyright'
   ),
	array(
		'id'          => 'proland_footerbgcolor',
		'label'       => esc_html__( 'Footer Background  color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'copyright'
	),
	array(
		'id'          => 'proland_footerpoweredcolor',
		'label'       => esc_html__( 'Footer copyright text color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'copyright'
	),
	array(
		'id'          => 'proland_footersocialcolor',
		'label'       => esc_html__( 'Footer Social color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'copyright'
	),
	array(
		'id'          => 'proland_footersocialhovercolor',
		'label'       => esc_html__( 'Footer Social Icon hover color ', 'proland' ),
		'desc'        => esc_html__( 'Please select color', 'proland' ),
		'type'        => 'colorpicker',
		'section'     => 'copyright'
	),

  /**  GOOGLE FONTS  SETTINGS.  **/

	array(
		'id'        => 'body_google_fonts',
		'label'     => esc_html__( 'Google Fonts', 'proland'  ),
		'desc'      => esc_html__( 'Add Google Font and after the save settings follow these steps Dashboproland > Appearance > Theme Options > Typography', 'proland' ),
		'type'      => 'google-fonts',
		'section'   => 'google_fonts',
		'operator'  => 'and'
	),

  /**  TYPOGRAPHY  SETTINGS.  **/

  array(
    'id'        => 'proland_typgrph',
    'label'     => esc_html__( 'Typography', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrpha',
    'label'     => esc_html__( 'Typography a', 'proland' ),
    'desc'      => esc_html__( 'The Typography a option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph1',
    'label'     => esc_html__( 'Typography h1', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph2',
    'label'     => esc_html__( 'Typography h2', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph3',
    'label'     => esc_html__( 'Typography h3', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph4',
    'label'     => esc_html__( 'Typography h4', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph5',
    'label'     => esc_html__( 'Typography h5', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph6',
    'label'     => esc_html__( 'Typography h6', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),
  array(
    'id'        => 'proland_typgrph7',
    'label'     => esc_html__( 'Typography p', 'proland' ),
    'desc'      => esc_html__( 'The Typography option type is for adding typography styles to your site.', 'proland' ),
    'type'      => 'typography',
    'section'   => 'typography',
    'operator'  => 'and'
  ),


    )
);
 /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings );
  }
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
}
